@@ -179,6 +179,7 @@ from .drawing import (
     draw_lines,
     draw_geodesics,
     draw_polylines,
+    draw_breps,
     draw_faces,
     draw_cylinders,
     draw_pipes,
@@ -275,6 +276,7 @@ __all__ = [
     'draw_lines',
     'draw_geodesics',
     'draw_polylines',
+    'draw_breps',
     'draw_faces',
     'draw_cylinders',
     'draw_pipes',
